__name__ = 'netbox_contextmenus'
__version__ = '1.4.5'
__description__ = 'Add context menu to links in NetBox'
__author__ = 'Pieter Lambrecht'
__author_email__ = 'pieter.lambrecht@gmail.com'
__url__ = 'https://github.com/PieterL75/netbox_contextmenus'
